Inverse Problem#
See also
See Terminology & Notation for definitions of prior, posterior, forward operator, and other inverse problem terminology.
Constructor#
|
Inverse problem combining observations, priors, and forward model. |
Inputs#
Observation vector. |
|
Prior state vector. |
|
Forward operator mapping state space to observation space. |
|
Covariance matrix representing prior error. |
|
Covariance matrix representing model-data mismatch (observation error). |
|
Optional constant term added to the forward model (e.g., background or bias). |
Solving the Inverse Problem#
Return the fitted estimator (raises if not solved). |
|
|
Solve the inverse problem using the specified estimator. |
Results#
Posterior state estimate. |
|
Posterior error covariance. |
|
Modeled observations using the prior (H @ prior). |
|
Modeled observations (H @ posterior). |
|
Kalman gain matrix (K). |
|
Averaging kernel matrix (A). |
Selection and indexing#
|
Get block from a component (Vector or Matrix). |
Serialization#
|
Load object from a pickle file. |
|
Save object to a pickle file. |