Operators#
Operators perfom mathematical operations on blocks and vectors, such as addition, multiplication, etc. The ForwardOperator class represents the forward operator in an inverse problem, and provides methods for applying the operator and its adjoint to vectors.
ForwardOperator#
Constructor#
|
Forward operator matrix mapping state vectors to observation space. |
Attributes and underlying data#
Name of the structure, used for error messages and block naming. |
|
The underlying data, which must be numeric and non-NaN. |
|
Return the index of the underlying data. |
|
Return the observation space index (rows). |
|
Return the columns of the underlying DataFrame. |
|
Return the state space index (columns). |
|
Return the shape of the underlying data. |
|
Return values as numpy array or sparse matrix. |
|
Accessor for retrieving MatrixBlock instances from the Matrix. |
Conversion#
|
Create a copy of the structure. |
Get the underlying DataFrame data. |
|
Get the underlying data as a NumPy array. |
Reindexing / selection / label manipulation#
|
Cross-select data based on index/column values. |
|
Return a new instance with data reindexed to the specified index and columns. |
|
Round float indices on the specified axis to given decimals. |
Serialization#
Load object from a pickle file. |
|
|
Save object to a pickle file. |
Sparse support#
True if the internal DataFrame uses pandas sparse storage. |
|
|
Return a copy with sparse internal storage. |
Return a copy with dense internal storage. |
Computations#
|
Convolve a state vector through the forward operator. |
Convolution#
The convolve method applies the forward operator to a vector, and can be used to compute the predicted observations given a model state.
|
Convolve a state vector with a forward operator matrix. |