Multi-Block Structures#
Vector#
Constructor#
|
State or observation vector composed of one or more Block objects. |
Attributes and underlying data#
The name of the underlying Series. |
|
The underlying data, which must be numeric and non-NaN. |
|
Return the index of the underlying data. |
|
Return the shape of the underlying data. |
|
Return the values as a numpy array. |
|
Accessor for retrieving Block instances from the Vector. |
Conversion#
|
Create a copy of the structure. |
Get the underlying Series data. |
|
Get the underlying data as a NumPy array. |
|
Convert the Vector to xarray. |
Reindexing / selection / label manipulation#
|
Get block by name. |
|
Cross-select data based on index/column values. |
|
Return a new instance with data reindexed to the specified index and columns. |
|
Round float indices on the specified axis to given decimals. |
Serialization#
|
Load object from a pickle file. |
|
Save object to a pickle file. |
Matrix#
Constructor#
|
Base class for all matrix-like objects in the inversion framework. |
Attributes and underlying data#
Name of the structure, used for error messages and block naming. |
|
The underlying data, which must be numeric and non-NaN. |
|
Return the index of the underlying data. |
|
Return the columns of the underlying DataFrame. |
|
Return the shape of the underlying data. |
|
Return values as numpy array or sparse matrix. |
Conversion#
|
Create a copy of the structure. |
Get the underlying DataFrame data. |
|
Get the underlying data as a NumPy array. |
Reindexing / selection / label manipulation#
|
Get the submatrix DataFrame for the given (row_block, col_block) tuple. |
|
Cross-select data based on index/column values. |
|
Return a new instance with data reindexed to the specified index and columns. |
|
Round float indices on the specified axis to given decimals. |
Computations#
|
Scale the matrix by a scalar factor. |
Binary operations#
|
Add two Matrix instances. |
Serialization#
|
Load object from a pickle file. |
|
Save object to a pickle file. |
Sparse support#
True if the internal DataFrame uses pandas sparse storage. |
|
|
Return a copy with sparse internal storage. |
Return a copy with dense internal storage. |